package GUI;

import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.XMLDecoder;
import java.beans.XMLEncoder;
import java.io.*;

import javax.swing.*;

import data.Informace;

/**
 * Tda s metodou main. Obsahuje vytvoen menu a GUI.
 * @author Ondej Papk
 *
 */
public class Main {
	/**
	 * JPanel se vemi obrazovkami.
	 */
	static JPanel obrazovky=new JPanel(new CardLayout());
	/**
	 * obrazovka pro zahjen hry.
	 */
	public static PanelHry hrat=new PanelHry();
	/**
	 * obrazovka pro vytven karet.
	 */
	public static PanelKaret karty;
	/**
	 * obrazovka pro vytvoen vzhledu.
	 */
	public static PanelVzhledu vzhled;
	/**
	 * obrazovka pro zadn pravidel.
	 */
	public static PanelPravidel pravidla;
	/**
	 * obrazovka pro zadn UI.
	 */
	public static PanelUI UI;
	/**
	 * Informace o vytven he.
	 */
	public static Informace informace=new Informace(karty,vzhled,pravidla,UI);
	/**
	 * JFrame hlavnho programu.
	 */
	public static JFrame fram;
	
	/**
	 * Vytvo menu.
	 * @param frame - JFrame hlavnho programu
	 * @return menu
	 */
	static JMenuBar createMenu(final JFrame frame){
		JMenuBar menu=new JMenuBar();
		final JMenu menuN=new JMenu("Nvrh");
		JMenu menuS=new JMenu("Soubor");
		JMenuItem item=new JMenuItem("Hrt");
		menuS.add(item);
		item.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				((CardLayout)obrazovky.getLayout()).show(obrazovky, "hrat");
			}
		});
		item=new JMenuItem("Vytvoit novou");
		menuS.add(item);
		item.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				karty=new PanelKaret(frame);
				vzhled=new PanelVzhledu(frame);
				pravidla=new PanelPravidel(frame);
				UI=new PanelUI(frame);
				menuN.setEnabled(true);
				obrazovky.removeAll();
				obrazovky.add("hrat", hrat);
				obrazovky.add("karty", karty);
				obrazovky.add("vzhled", new JScrollPane(vzhled));
				obrazovky.add("pravidla", pravidla);
				obrazovky.add("UI", UI);
				informace=new Informace(karty,vzhled,pravidla,UI);
				informace.setNazev(null);
			}
		});
		item=new JMenuItem("Nast");
		menuS.add(item);
		item.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				try{
					final JFileChooser chooser=new JFileChooser(new File(Main.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath()).getParentFile().getPath()+File.separator+"hry");
					chooser.setDialogType(JFileChooser.OPEN_DIALOG);
					int i=chooser.showOpenDialog(fram);
					if(i==JFileChooser.APPROVE_OPTION){
						final JDialog dialog=new JDialog(fram, "Natn", true);
						dialog.setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
						dialog.add(new JLabel("Nat se..."));
						dialog.pack();
						dialog.setLocationRelativeTo(fram);
						new SwingWorker<Object, Object>(){
							protected Object doInBackground(){
								File f=chooser.getSelectedFile();
								try{
									XMLDecoder decoder=new XMLDecoder(new FileInputStream(f));
									informace=(Informace) decoder.readObject();
									decoder.close();
									karty=informace.getKarty();
									vzhled=informace.getVzhled();
									pravidla=informace.getPravidla();
									UI=informace.getUI();
									obrazovky.removeAll();
									obrazovky.add("hrat", hrat);
									obrazovky.add("karty", karty);
									obrazovky.add("vzhled", new JScrollPane(vzhled));
									obrazovky.add("pravidla", pravidla);
									obrazovky.add("UI", UI);
									menuN.setEnabled(true);
									karty.obnovit();
									vzhled.obnovit();
									pravidla.obnovit();
									UI.obnovit();
									((CardLayout)obrazovky.getLayout()).show(obrazovky, "hrat");
									for(Component a:obrazovky.getComponents()){
										a.update(a.getGraphics());
									}
								}
								catch(Exception e){
								}
								return null;
							}
							protected void done(){
								dialog.setVisible(false);
							}
						}.execute();
						dialog.setVisible(true);
					}
				}catch(Exception e1){}
			}
		});
		item=new JMenuItem("Uloit");
		menuS.add(item);
		item.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				if(!informace.getNazev().equals(null)){
					final JDialog dialog=new JDialog(fram, "Ukldn", true);
					dialog.setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
					dialog.add(new JLabel("Ukld se..."));
					dialog.pack();
					dialog.setLocationRelativeTo(fram);
					new SwingWorker<Object, Object>(){
						protected Object doInBackground(){
							try{
								XMLEncoder encoder=new XMLEncoder(new FileOutputStream(new File(Main.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath()).getParentFile().getPath()+File.separator+"hry"+File.separatorChar+informace.getNazev()+".xml"));
								Informace inf=new Informace(karty,vzhled,pravidla,UI);
								inf.setNazev(informace.getNazev());
								informace=inf;
								encoder.writeObject(informace);
								encoder.close();
								hrat.hra.removeAllItems();
								for(File x:(new File(new File(Main.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath()).getParentFile().getPath()+File.separator+"hry")).listFiles()){
									hrat.hra.addItem(x.getName().substring(0, x.getName().length()-4));
								}
							}
							catch(FileNotFoundException e){
							} catch (Exception e1){}
							return null;
						}
						protected void done(){
							dialog.setVisible(false);
						}
					}.execute();
					dialog.setVisible(true);
				}
			}
		});
		item=new JMenuItem("Uloit jako");
		menuS.add(item);
		item.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				try{
					final JFileChooser chooser=new JFileChooser(new File(Main.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath()).getParentFile().getPath()+File.separator+"hry");
					chooser.setDialogType(JFileChooser.SAVE_DIALOG);
					int i=chooser.showSaveDialog(fram);
					if(i==JFileChooser.APPROVE_OPTION){
						final JDialog dialog=new JDialog(fram, "Ukldn", true);
						dialog.setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
						dialog.add(new JLabel("Ukld se..."));
						dialog.pack();
						dialog.setLocationRelativeTo(fram);
						new SwingWorker<Object, Object>(){
							protected Object doInBackground(){
								try {
									File f=chooser.getSelectedFile();
									XMLEncoder encoder=new XMLEncoder(new FileOutputStream(f.getAbsolutePath()+".xml"));
									informace=new Informace(karty,vzhled,pravidla,UI);
									informace.setNazev(f.getName());
									encoder.writeObject(informace);
									encoder.close();
									hrat.hra.removeAllItems();
									for(File x:(new File(new File(Main.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath()).getParentFile().getPath()+File.separator+"hry")).listFiles()){
										hrat.hra.addItem(x.getName().substring(0, x.getName().length()-4));
									}
								} catch (FileNotFoundException e1) {
								} catch (Exception e2){}
								return null;
							}
							protected void done(){
								dialog.setVisible(false);
							}
						}.execute();
						dialog.setVisible(true);
					}
				} catch (Exception e1){}
			}
		});
		item=new JMenuItem("Konec");
		menuS.add(item);
		item.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				System.exit(0);
			}
		});
		menu.add(menuS);
		menuN.setEnabled(false);
		item=new JMenuItem("Karty");
		menuN.add(item);
		item.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				((CardLayout)obrazovky.getLayout()).show(obrazovky, "karty");
			}
		});
		item=new JMenuItem("Vzhled");
		menuN.add(item);
		item.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				((CardLayout)obrazovky.getLayout()).show(obrazovky, "vzhled");
			}
		});
		item=new JMenuItem("Pravidla");
		menuN.add(item);
		item.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				((CardLayout)obrazovky.getLayout()).show(obrazovky, "pravidla");
			}
		});
		item=new JMenuItem("UI");
		menuN.add(item);
		item.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				((CardLayout)obrazovky.getLayout()).show(obrazovky, "UI");
			}
		});
		menu.add(menuN);
		return menu;
	}
	
	/**
	 * Vytvo GUI.
	 */
	static void createAndShowGUI(){
		JFrame.setDefaultLookAndFeelDecorated(true);
		JFrame frame = new JFrame("GKH");
		fram=frame;
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.setJMenuBar(createMenu(frame));
		obrazovky.add("hrat", hrat);
		File f=null;
		try{
			for(File x:new File(new File(Main.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath()).getParentFile().getPath()+File.separator+"hry").listFiles()){
				hrat.hra.addItem(x.getName().substring(0, x.getName().length()-4));
			}
		}
		catch(Exception e){}
		frame.getContentPane().add(obrazovky);
		frame.pack();
		frame.setMinimumSize(new Dimension(700, 500));
		frame.setSize(700, 500);
		frame.setVisible(true);
	}
	
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		//System.err.close();
		javax.swing.SwingUtilities.invokeLater(new Runnable(){
			public void run() {
				createAndShowGUI();
			}
		});
	}

}
