package GUI;

import java.awt.*;
import java.awt.event.*;
import java.beans.XMLDecoder;
import java.beans.XMLEncoder;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.*;
import java.util.List;

import javax.swing.*;

import data.Informace;

/**
 * Tda reprezentujc obrazovku pro zadvn karet.
 * @author Ondej Papk
 *
 */
public class PanelKaret extends JPanel{
	/**
	 * ID pro serializaci
	 */
	private static final long serialVersionUID = 6937010557216040757L;
	/**
	 * JComboBox urujc kartu, kter je vybrna k upravovn.
	 */
	private JComboBox<String> zvolena=new JComboBox<String>();
	/**
	 * JPanel, do kterho se vkldaj jednotliv karty.
	 */
	private JPanel karty=new JPanel(new CardLayout());
	/**
	 * Mapa JPanel s jednotlivmi kartami. Kl je jmno karty a obsahem je JPanel s informacemi o kart.
	 */
	private Map<String, JPanel> seznam=new HashMap<String, JPanel>();
	/**
	 * Seznam parametr, kter mohou karty mt.
	 */
	private List<String> seznamParametru=new LinkedList<String>();
	/**
	 * Mapa tlatek na zmnu obrzku. Klem je nzev karty a obsahem je tlatko, 
	 * kter oteve dialog, ve kterm se vybere obrzek pro danou kartu.
	 */
	private Map<String, JButton> zmeny=new HashMap<String, JButton>();
	/**
	 * Mapa JTextField s poty a nzvy karet. Klem je nzev karty a obsah je pole velikosti dva, kde prvn je JTextField s potem kopi
	 * dan karty v balku a druh je JTextField, do kterho se zadv nzev karty.
	 */
	private Map<String, JTextField[]> pocty=new HashMap<String, JTextField[]>();
	/**
	 * Mapy JTextField s parametry jednotlivch karet. Klem v prvn map je nzev karty a klem v druh map je nzev parametru
	 * karty. Hodnotou je potom JTextField, do kterho se zapisuje hodnota parametru.
	 */
	private Map<String, Map<String, JTextField>> parametry=new HashMap<String, Map<String, JTextField>>();
	/**
	 * Mapa obrzk karet. Klem je nzev karet a obsahem je JLabel, kter m jako Icon nastaven zvolen obrzek.
	 */
	private Map<String, JLabel> obrazky=new HashMap<String, JLabel>();
	/**
	 * Tlatka, ke kterm je teba pidat listenery po naten. Jedn se po ad o tlatka pro zmnu parametr,
	 * pidn karty, odebrn karty, naten balku a uloen balku.
	 */
	private JButton[] kObnoveni=new JButton[5];
	/**
	 * JTextFieldy, ke kterm je teba po naten pidat listenery. Klem je nzev karty a hodnotou je JTextField pro zadvn nzvu karty.
	 */
	private Map<String, JTextField> kObnoveni2=new HashMap<String, JTextField>();
	
	/**
	 * Konstruktor pro vytvoen obrazovky. 
	 */
	public PanelKaret(final JFrame f){
		this.setLayout(new BorderLayout());
		JPanel panel=new JPanel(new GridLayout(6,1));
		JButton button=new JButton("Uloit balek");
		panel.add(button);
		kObnoveni[4]=button;
		button.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				try{
					final JFileChooser chooser=new JFileChooser(new File(PanelKaret.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath()).getParentFile().getPath()+File.separator+"obrazky");
					chooser.setDialogType(JFileChooser.SAVE_DIALOG);
					int i=chooser.showSaveDialog(f);
					if(i==JFileChooser.APPROVE_OPTION){
						final JDialog dialog=new JDialog(f, "Ukldn", true);
						dialog.setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
						dialog.add(new JLabel("Ukld se..."));
						dialog.pack();
						dialog.setLocationRelativeTo(f);
						new SwingWorker<Object, Object>(){
							protected Object doInBackground(){
								try {
									File f=chooser.getSelectedFile();
									XMLEncoder encoder=new XMLEncoder(new FileOutputStream(f.getAbsolutePath()+".xml"));
									encoder.writeObject(Main.karty);
									encoder.close();
								} catch (FileNotFoundException e1) {
								}
								return null;
							}
							protected void done(){
								dialog.setVisible(false);
							}
						}.execute();
						dialog.setVisible(true);
					}
				}catch(Exception e){}
			}
		});
		button=new JButton("Nast balek");
		panel.add(button);
		kObnoveni[3]=button;
		button.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				try{
					final JFileChooser chooser=new JFileChooser(new File(PanelKaret.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath()).getParentFile().getPath()+File.separator+"obrazky");
					chooser.setDialogType(JFileChooser.OPEN_DIALOG);
					int i=chooser.showOpenDialog(f);
					if(i==JFileChooser.APPROVE_OPTION){
						final JDialog dialog=new JDialog(f, "Natn", true);
						dialog.setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
						dialog.add(new JLabel("Nat se..."));
						dialog.pack();
						dialog.setLocationRelativeTo(f);
						new SwingWorker<Object, Object>(){
							protected Object doInBackground(){
								File f=chooser.getSelectedFile();
								try{
									XMLDecoder decoder=new XMLDecoder(new FileInputStream(f));
									PanelKaret k=(PanelKaret) decoder.readObject();
									decoder.close();
									Main.karty=k;
									Main.obrazovky.removeAll();
									Main.obrazovky.add("hrat", Main.hrat);
									Main.obrazovky.add("karty", Main.karty);
									Main.obrazovky.add("vzhled", new JScrollPane(Main.vzhled));
									Main.obrazovky.add("pravidla", Main.pravidla);
									Main.obrazovky.add("UI", Main.UI);
									k.obnovit();
									((CardLayout)Main.obrazovky.getLayout()).show(Main.obrazovky, "karty");
								}
								catch(FileNotFoundException e1){
								}
								return null;
							}
							protected void done(){
								dialog.setVisible(false);
							}
						}.execute();
						dialog.setVisible(true);
					}
				}catch(Exception e1){}
			}
		});
		button=new JButton("Zmnit parametry");
		panel.add(button);
		kObnoveni[0]=button;
		button.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				createAndShowDialog();
			}
		});
		panel.add(zvolena);
		zvolena.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				((CardLayout) karty.getLayout()).show(karty, (String) zvolena.getSelectedItem());
			}
		});
		button=new JButton("Nov karta");
		panel.add(button);
		kObnoveni[1]=button;
		button.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				vloz();
			}
		});
		button=new JButton("Odebrat kartu");
		panel.add(button);
		kObnoveni[2]=button;
		button.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				zmeny.remove(zvolena.getSelectedItem());
				pocty.remove(zvolena.getSelectedItem());
				parametry.remove(zvolena.getSelectedItem());
				karty.remove(seznam.get(zvolena.getSelectedItem()));
				seznam.remove(zvolena.getSelectedItem());
				zvolena.removeItem(zvolena.getSelectedItem());
				obrazky.remove(zvolena.getSelectedItem());
				if(zvolena.getItemCount()==0){
					vloz();
				}
				else{
					zvolena.setSelectedIndex(0);
				}
			}
		});
		this.add(panel, BorderLayout.NORTH);
		this.add(karty, BorderLayout.SOUTH);
		if(zvolena.getItemCount()==0){
			vloz();
		}
	}
	
	/**
	 * Pid novou kartu. Dojde k vytvoen JPanelu pro novou kartu, kter se vlo na konec seznamu karet.
	 */
	void vloz(){
		int i=0;
		int n=1;
		for(;i<n;++i){
			for(int j=0;j<zvolena.getItemCount();++j){
				if(zvolena.getItemAt(j).equals(((Integer) i).toString())){
					++n;
				}
			}
		}
		--i;
		zvolena.addItem(((Integer) i).toString());
		JPanel vnejsiPanel=new JPanel(new BorderLayout());
		JPanel vnitrniPanel=new JPanel(new GridLayout(0,2));
		vnitrniPanel.add(new JLabel());
		JButton buttonZmena=new JButton("Zmnit obrzek");
		vnitrniPanel.add(buttonZmena);
		zmeny.put(((Integer) i).toString(), buttonZmena);
		buttonZmena.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				try{
					JFileChooser chooser=new JFileChooser(new File(PanelKaret.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath()).getParentFile().getPath()+File.separator+"obrazky");
					chooser.setDialogType(JFileChooser.OPEN_DIALOG);
					int i=chooser.showOpenDialog(null);
					if(i==JFileChooser.APPROVE_OPTION){
						File f=chooser.getSelectedFile();
						obrazky.get(zvolena.getSelectedItem()).setIcon(new ImageIcon(f.getAbsolutePath()));
						obrazky.get(zvolena.getSelectedItem()).updateUI();
						obrazky.get(zvolena.getSelectedItem()).setName(f.getName());
					}
				}catch(Exception e){}
			}
		});
		vnitrniPanel.add(new JLabel("Poet:"));
		JTextField tf=new JTextField("1");
		vnitrniPanel.add(tf);
		pocty.put(((Integer) i).toString(), new JTextField[2]);
		pocty.get(((Integer) i).toString())[0]=tf;
		vnitrniPanel.add(new JLabel("Nzev:"));
		final JTextField tfNazev=new JTextField(((Integer) i).toString());
		pocty.get(((Integer) i).toString())[1]=tfNazev;
		kObnoveni2.put(((Integer) i).toString(), tfNazev);
		tfNazev.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				String s=(String) zvolena.getSelectedItem();
				zvolena.setSelectedItem(tfNazev.getText());
				if(s.equals(zvolena.getSelectedItem())&&!s.equals(tfNazev.getText())){
					obrazky.put(tfNazev.getText(), obrazky.get(s));
					obrazky.remove(s);
					zmeny.put(tfNazev.getText(), zmeny.get(s));
					zmeny.remove(s);
					pocty.put(tfNazev.getText(), pocty.get(s));
					pocty.remove(s);
					parametry.put(tfNazev.getText(), parametry.get(s));
					parametry.remove(s);
					karty.remove(seznam.get(zvolena.getSelectedItem()));
					karty.add(tfNazev.getText(), seznam.get(zvolena.getSelectedItem()));
					seznam.put(tfNazev.getText(), seznam.get(zvolena.getSelectedItem()));
					seznam.remove(zvolena.getSelectedItem());
					zvolena.insertItemAt(tfNazev.getText(), zvolena.getSelectedIndex());
					zvolena.removeItem(zvolena.getSelectedItem());
					zvolena.setSelectedItem(tfNazev.getText());
					kObnoveni2.remove(s);
					kObnoveni2.put((String) zvolena.getSelectedItem(), tfNazev);
				}
				else{
					tfNazev.setText(s);
					zvolena.setSelectedItem(s);
				}
			}
		});
		vnitrniPanel.add(tfNazev);
		parametry.put(((Integer) i).toString(), new HashMap<String, JTextField>());
		for(int j=0;j<seznamParametru.size();++j){
			vnitrniPanel.add(new JLabel(seznamParametru.get(j)+":"));
			JTextField t=new JTextField();
			vnitrniPanel.add(t);
			parametry.get(((Integer) i).toString()).put(seznamParametru.get(j), t);
		}
		JLabel obrazek=new JLabel();
		obrazky.put(((Integer) i).toString(), obrazek);
		vnejsiPanel.add(obrazek, BorderLayout.EAST);
		vnejsiPanel.add(vnitrniPanel, BorderLayout.WEST);
		seznam.put(((Integer) i).toString(), vnejsiPanel);
		karty.add(((Integer) i).toString(), vnejsiPanel);
		zvolena.setSelectedItem(((Integer) i).toString());
	}
	
	/**
	 * Vytvo dialog pro zmnu parametr. V tomto dialogu uivatel nastavuje jak mohou mt karty parametry. Nzvy parametr se
	 * zadvaj do JTextField, vedle kterch jsou tlatka plus a mnus pro pidn dalho parametru resp. odebrn stvajcho parametru.
	 */
	void createAndShowDialog(){
		final JDialog dialog=new JDialog();
		dialog.setTitle("Zmna parametr");
		dialog.setAlwaysOnTop(true);
		final List<Component> komponenty=new LinkedList<Component>();
		final JPanel panel=new JPanel(new GridLayout(0,3));
		JLabel j=new JLabel();
		panel.add(j);
		komponenty.add(j);
		j=new JLabel();
		panel.add(j);
		komponenty.add(j);
		final JButton plus=new JButton("+");
		komponenty.add(plus);
		plus.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				panel.removeAll();
				for(int i=0;i<komponenty.size();++i){
					if(e.getSource()==komponenty.get(i)){
						panel.add(komponenty.get(i));
						JTextField tf=new JTextField();
						panel.add(tf);
						++i;
						komponenty.add(i, tf);
						final JButton minus=new JButton("-");
						minus.addActionListener(new ActionListener() {
							
							@Override
							public void actionPerformed(ActionEvent arg0) {
								int i=0;
								for(;i<komponenty.size();++i){
									if(komponenty.get(i)==minus)
										break;
								}
								komponenty.remove(i+1);
								komponenty.remove(i);
								komponenty.remove(i-1);
								panel.removeAll();
								for(Component j:komponenty){
									panel.add(j);
								}
								dialog.pack();
							}
						});
						panel.add(minus);
						++i;
						komponenty.add(i, minus);
						JButton b=new JButton("+");
						b.addActionListener(plus.getActionListeners()[0]);
						panel.add(b);
						++i;
						komponenty.add(i, b);
					}
					else{
						panel.add(komponenty.get(i));
					}
				}
				dialog.pack();
			}
		});
		panel.add(plus);
		for(int i=0;i<seznamParametru.size();++i){
			JTextField t=new JTextField(seznamParametru.get(i));
			komponenty.add(t);
			panel.add(t);
			final JButton m=new JButton("-");
			m.addActionListener(new ActionListener() {
				
				@Override
				public void actionPerformed(ActionEvent arg0) {
					int i=0;
					for(;i<komponenty.size();++i){
						if(komponenty.get(i)==m)
							break;
					}
					komponenty.remove(i+1);
					komponenty.remove(i);
					komponenty.remove(i-1);
					panel.removeAll();
					for(Component j:komponenty){
						panel.add(j);
					}
					dialog.pack();
				}
			});
			komponenty.add(m);
			panel.add(m);
			JButton pl=new JButton("+");
			pl.addActionListener(plus.getActionListeners()[0]);
			komponenty.add(pl);
			panel.add(pl);
		}
		JButton ok=new JButton("OK");
		ok.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				seznamParametru.clear();
				for(int i=3;i<komponenty.size()-3;i+=3){
					seznamParametru.add(((JTextField) komponenty.get(i)).getText());
				}
				for(int i=0;i<seznamParametru.size();++i)
					for(int j=i+1;j<seznamParametru.size();++j)
						if(seznamParametru.get(i).equals(seznamParametru.get(j)))
							seznamParametru.remove(j);
				for(String s:seznam.keySet()){
					JPanel karta=(JPanel) seznam.get(s).getComponent(1);
					JPanel nove=new JPanel(new GridLayout(0, 2));
					nove.add(new JLabel());
					nove.add(zmeny.get(s));
					nove.add(new JLabel("Poet:"));
					nove.add(pocty.get(s)[0]);
					nove.add(new JLabel("Nzev:"));
					nove.add(pocty.get(s)[1]);
					for(String i:seznamParametru){
						nove.add(new JLabel(i+":"));
						JTextField tf=new JTextField();
						if(parametry.get(s).containsKey(i))
							tf=parametry.get(s).get(i);
						else
							parametry.get(s).put(i, tf);
						nove.add(tf);
					}
					seznam.get(s).remove(karta);
					seznam.get(s).add(nove, BorderLayout.WEST);
				}
				dialog.setVisible(false);
				karty.updateUI();
			}
		});
		JButton storno=new JButton("Storno");
		storno.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				dialog.setVisible(false);
			}
		});
		panel.add(ok);
		panel.add(new JLabel());
		panel.add(storno);
		komponenty.add(ok);
		komponenty.add(new JLabel());
		komponenty.add(storno);
		dialog.add(panel);
		dialog.pack();
		dialog.setVisible(true);
	}
	
	/**
	 * Pid listenery po naten. Kdy dojde k naten hry do programu, tak je poteba opt pidat ke vem komponentm jejich listenery.
	 */
	public void obnovit(){
		karty.removeAll();
		for(int i=0;i<zvolena.getItemCount();++i){
			karty.add(zvolena.getItemAt(i), seznam.get(zvolena.getItemAt(i)));
		}
		try{
			for(String key:obrazky.keySet()){
				obrazky.get(key).setIcon(new ImageIcon(new File(PanelKaret.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath()).getParentFile().getPath()+File.separator+"obrazky"+File.separator+obrazky.get(key).getName()));
			}
		}catch(Exception e){}
		zvolena.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				((CardLayout) karty.getLayout()).show(karty, (String) zvolena.getSelectedItem());
			}
		});
		zvolena.setSelectedIndex(0);
		kObnoveni[0].addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				createAndShowDialog();
			}
		});
		kObnoveni[1].addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				vloz();
			}
		});
		kObnoveni[2].addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				obrazky.remove(zvolena.getSelectedItem());
				zmeny.remove(zvolena.getSelectedItem());
				pocty.remove(zvolena.getSelectedItem());
				parametry.remove(zvolena.getSelectedItem());
				karty.remove(seznam.get(zvolena.getSelectedItem()));
				seznam.remove(zvolena.getSelectedItem());
				zvolena.removeItem(zvolena.getSelectedItem());
				if(zvolena.getItemCount()==0){
					vloz();
				}
				else{
					zvolena.setSelectedIndex(0);
				}
			}
		});
		for(int i=0;i<zvolena.getItemCount();++i){
			final JTextField tfNazev=kObnoveni2.get(zvolena.getItemAt(i));
			tfNazev.addActionListener(new ActionListener() {
				
				@Override
				public void actionPerformed(ActionEvent arg0) {
					String s=(String) zvolena.getSelectedItem();
					zvolena.setSelectedItem(tfNazev.getText());
					if(s.equals(zvolena.getSelectedItem())&&!s.equals(tfNazev.getText())){
						obrazky.put(tfNazev.getText(), obrazky.get(s));
						obrazky.remove(s);
						zmeny.put(tfNazev.getText(), zmeny.get(s));
						zmeny.remove(s);
						pocty.put(tfNazev.getText(), pocty.get(s));
						pocty.remove(s);
						parametry.put(tfNazev.getText(), parametry.get(s));
						parametry.remove(s);
						karty.remove(seznam.get(zvolena.getSelectedItem()));
						karty.add(tfNazev.getText(), seznam.get(zvolena.getSelectedItem()));
						seznam.put(tfNazev.getText(), seznam.get(zvolena.getSelectedItem()));
						seznam.remove(zvolena.getSelectedItem());
						zvolena.insertItemAt(tfNazev.getText(), zvolena.getSelectedIndex());
						zvolena.removeItem(zvolena.getSelectedItem());
						zvolena.setSelectedItem(tfNazev.getText());
						kObnoveni2.remove(s);
						kObnoveni2.put((String) zvolena.getSelectedItem(), tfNazev);
					}
					else{
						tfNazev.setText(s);
						zvolena.setSelectedItem(s);
					}
				}
			});
		}
		for(int i=0;i<zvolena.getItemCount();++i){
			zmeny.get(zvolena.getItemAt(i)).addActionListener(new ActionListener() {
				
				@Override
				public void actionPerformed(ActionEvent arg0) {
					try{
						JFileChooser chooser=new JFileChooser(new File(PanelKaret.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath()).getParentFile().getPath()+File.separator+"obrazky");
						chooser.setDialogType(JFileChooser.OPEN_DIALOG);
						int i=chooser.showOpenDialog(null);
						if(i==JFileChooser.APPROVE_OPTION){
							File f=chooser.getSelectedFile();
							obrazky.get(zvolena.getSelectedItem()).setIcon(new ImageIcon(f.getAbsolutePath()));
							obrazky.get(zvolena.getSelectedItem()).updateUI();
							obrazky.get(zvolena.getSelectedItem()).setName(f.getName());
						}
					}catch(Exception e){}
				}
			});
		}
		kObnoveni[3].addActionListener(new ActionListener(){

			@Override
			public void actionPerformed(ActionEvent e) {
				try{
					final JFileChooser chooser=new JFileChooser(new File(PanelKaret.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath()).getParentFile().getPath()+File.separator+"obrazky");
					chooser.setDialogType(JFileChooser.OPEN_DIALOG);
					int i=chooser.showOpenDialog(Main.fram);
					if(i==JFileChooser.APPROVE_OPTION){
						final JDialog dialog=new JDialog(Main.fram, "Natn", true);
						dialog.setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
						dialog.add(new JLabel("Nat se..."));
						dialog.pack();
						dialog.setLocationRelativeTo(Main.fram);
						new SwingWorker<Object, Object>(){
							protected Object doInBackground(){
								File f=chooser.getSelectedFile();
								try{
									XMLDecoder decoder=new XMLDecoder(new FileInputStream(f));
									PanelKaret k=(PanelKaret) decoder.readObject();
									decoder.close();
									Main.karty=k;
									Main.obrazovky.removeAll();
									Main.obrazovky.add("hrat", Main.hrat);
									Main.obrazovky.add("karty", Main.karty);
									Main.obrazovky.add("vzhled", new JScrollPane(Main.vzhled));
									Main.obrazovky.add("pravidla", Main.pravidla);
									Main.obrazovky.add("UI", Main.UI);
									k.obnovit();
									((CardLayout)Main.obrazovky.getLayout()).show(Main.obrazovky, "karty");
								}
								catch(FileNotFoundException e1){
								}
								return null;
							}
							protected void done(){
								dialog.setVisible(false);
							}
						}.execute();
						dialog.setVisible(true);
					}
				}catch(Exception e1){}
			}
		});
		kObnoveni[4].addActionListener(new ActionListener(){

			@Override
			public void actionPerformed(ActionEvent e) {
				try{
					final JFileChooser chooser=new JFileChooser(new File(PanelKaret.class.getProtectionDomain().getCodeSource().getLocation().toURI().getPath()).getParentFile().getPath()+File.separator+"obrazky");
					chooser.setDialogType(JFileChooser.SAVE_DIALOG);
					int i=chooser.showSaveDialog(Main.fram);
					if(i==JFileChooser.APPROVE_OPTION){
						final JDialog dialog=new JDialog(Main.fram, "Ukldn", true);
						dialog.setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
						dialog.add(new JLabel("Ukld se..."));
						dialog.pack();
						dialog.setLocationRelativeTo(Main.fram);
						new SwingWorker<Object, Object>(){
							protected Object doInBackground(){
								try {
									File f=chooser.getSelectedFile();
									XMLEncoder encoder=new XMLEncoder(new FileOutputStream(f.getAbsolutePath()+".xml"));
									encoder.writeObject(Main.karty);
									encoder.close();
								} catch (FileNotFoundException e1) {
								}
								return null;
							}
							protected void done(){
								dialog.setVisible(false);
							}
						}.execute();
						dialog.setVisible(true);
					}
				}catch(Exception e1){}
			}
		});
	}
	
	public PanelKaret(){}
	
	public JPanel getKarty(){
		return karty;
	}
	
	public void setKarty(JPanel a){
		karty=a;
	}
	
	public JComboBox<String> getZvolena(){
		return zvolena;
	}
	
	public void setZvolena(JComboBox<String> a){
		zvolena=a;
	}
	
	public Map<String, JPanel> getSeznam(){
		return seznam;
	}
	
	public void setSeznam(Map<String, JPanel> a){
		seznam=a;
	}
	
	public List<String> getSeznamParametru(){
		return seznamParametru;
	}
	
	public void setSeznamParametru(List<String> a){
		seznamParametru=a;
	}
	
	public Map<String, JButton> getZmeny(){
		return zmeny;
	}
	
	public void setZmeny(Map<String, JButton> a){
		zmeny=a;
	}
	
	public Map<String, JTextField[]> getPocty(){
		return pocty;
	}
	
	public void setPocty(Map<String, JTextField[]> a){
		pocty=a;
	}
	
	public Map<String, Map<String, JTextField>> getParametry(){
		return parametry;
	}
	
	public void setParametry(Map<String, Map<String, JTextField>> a){
		parametry=a;
	}
	
	public Map<String, JLabel> getObrazky(){
		return obrazky;
	}
	
	public void setObrazky(Map<String, JLabel> a){
		obrazky=a;
	}
	
	public JButton[] getKObnoveni(){
		return kObnoveni;
	}
	
	public void setKObnoveni(JButton[] a){
		kObnoveni=a;
	}
	
	public Map<String, JTextField> getKObnoveni2(){
		return kObnoveni2;
	}
	
	public void setKObnoveni2(Map<String, JTextField> a){
		kObnoveni2=a;
	}
}
